@@ -7,9 +7,6 @@ LOGIN_REDIRECT_WHITELIST = ["{{ CMS_HOST }}"]
 REGISTRATION_EXTRA_FIELDS["terms_of_service"] = "required"
 REGISTRATION_EXTRA_FIELDS["honor_code"] = "hidden"
 
-# This url must not be None and should not be used anywhere
-LEARNING_MICROFRONTEND_URL = "http://learn.openedx.org"
-
 # Fix media files paths
 PROFILE_IMAGE_BACKEND["options"]["location"] = os.path.join(
     MEDIA_ROOT, "profile-images/"
@@ -28,4 +25,4 @@ for folder in [DATA_DIR, LOG_DIR, MEDIA_ROOT, STATIC_ROOT_BASE, ORA2_FILEUPLOAD_
 
 {{ patch("openedx-lms-common-settings") }}
 
-######## End of common LMS settings
\ No newline at end of file
+######## End of common LMS settings
